import { Button, Tooltip } from 'antd';
import React, { useState, useRef, useEffect } from 'react';
import Expression from './Expression';
import style from './index.less'
import AddLink from '@/pages/MiniApp/EntWeChat/Welcome/components/link';
import { UserOutlined } from '@ant-design/icons';
type Props = {
    value?: any,
    onChange?: (v: any) => void
}
const EditablePre: React.FC<Props> = (props) => {
    const { value, onChange } = props
    const editableDivRef = useRef<HTMLDivElement>(null);
    const [savedRange, setSavedRange] = useState<Range | null>(null); // 用于存储光标位置
    //内容变更
    const handleInput = () => {
        if (editableDivRef.current) {
            const newStr = dataOutComp(editableDivRef.current.innerHTML)
            onChange?.(newStr);
        }
    };
    // 记录光标位置
    const handleFocusLoss = () => {
        const selection: any = window.getSelection();
        if (selection?.rangeCount > 0) {
            setSavedRange(selection.getRangeAt(0)); // 记录当前光标位置
        }
    };

    // 插入 HTML 到 savedRange 记录的光标位置
    const insertHtmlAtCursor = (html: string) => {
        if (!savedRange) return;  // 如果没有记录的光标位置，则不执行

        // 创建一个临时的 <div> 元素，用于将要插入的 HTML 包裹
        const tempDiv = document.createElement('div');
        tempDiv.innerHTML = html; // 创建包含 HTML 的临时元素
        const frag = document.createDocumentFragment();

        // 将临时元素的子元素添加到文档片段中
        let lastNode: Node | null = null;
        while (tempDiv.firstChild) {
            lastNode = frag.appendChild(tempDiv.firstChild);
        }

        // 如果 frag 为空，不执行插入操作
        if (!frag.firstChild) return;

        // 在记录的光标位置插入内容
        savedRange.deleteContents(); // 删除光标处的内容
        savedRange.insertNode(frag); // 将内容插入光标位置

        // 重新设置光标位置在插入内容之后
        if (lastNode) {
            const range = document.createRange();
            const selection = window.getSelection();

            range.setStartAfter(lastNode); // 将光标设置在插入内容的后面
            range.collapse(true); // 折叠范围（即设置为单一光标位置）

            selection?.removeAllRanges(); // 清除当前的所有选区
            selection?.addRange(range);   // 设置新的光标范围
        }

        handleInput();  // 触发内容变更处理
    };
    // 数据导入组件处理
    const dataInComp = (value: string) => {
        let newHtml = value?.split('\n')
            .map((line: any, index: any) => `<div>${line}</div>`)
            .join('');
        return newHtml.replace(/<div[^>]*>(\s|&nbsp;)*<\/div>/g, '')
    }
    // 数据导出出组件处理
    const dataOutComp = (value: string) => {
        const newStr = value
            .replace(/<div[^>]*>(\s|&nbsp;)*<\/div>/g, '') // 移除空的 <div> 标签
            .replace(/<div[^>]*>/g, '') // 将 <div> 替换为 ""
            .replace(/<\/div>/g, '\n') // 将 </div> 替换为 "\n"
        // .replace(/<br\s*\/?>/g, '\n') // 替换 <br> 为换行符
        return newStr
    }
    useEffect(() => {
        if (value) {
            if (editableDivRef.current) {
                editableDivRef.current.innerHTML = dataInComp(value)
            }
        }
    }, [])
    return (
        <div>
            <div style={{ display: 'flex', alignItems: 'center' }} className={style.header}>
                <Expression addEmo={insertHtmlAtCursor} range={savedRange as Range} />
                <AddLink showIcon onChange={(value) => {
                    if (value) {
                        insertHtmlAtCursor(`<a href="${value?.pagePath}" target="_blank">${value?.pagePath}</a>`)
                    }
                }} />
                <div>  <Tooltip title="@用户昵称"><Button size="small" type="link" onClick={() => insertHtmlAtCursor('@用户昵称')}><UserOutlined /></Button></Tooltip></div>
            </div>
            <div
                id="editText"
                ref={editableDivRef}
                contentEditable
                onInput={handleInput}
                onBlur={handleFocusLoss}
                style={{
                    border: '1px solid #ccc',
                    padding: '10px',
                    minHeight: '100px',
                    overflowY: 'auto',
                    whiteSpace: 'pre-wrap',
                    outline: 'none',
                }}
            >
                {/* 初始内容可以在此处放置 */}
            </div>
        </div>
    );
};

export default EditablePre;