import { ActionType, PageContainer, ProTable } from "@ant-design/pro-components"
import { Button, message, Modal, QRCode, Table } from "antd"
import { columns } from "./tableConfig"
import { useAjax } from "@/Hook/useAjax"
import { corpListOfPage, corpPreAuth, corpSyncAll } from "@/services/distributor/corpManage"
import { useRef, useState } from "react"
import { PlusOutlined } from "@ant-design/icons"

const Page: React.FC = () => {
    let getList = useAjax((params) => corpListOfPage(params), { type: 'table' })
    let [codeOpen, setCodeOpen] = useState<string>("")
    let [codeState, setCodeState] = useState<"active" | "loading" | "expired" | "scanned">("active")
    let CorpPreAuth = useAjax(() => corpPreAuth())
    let CorpSyncAll = useAjax((corpId) => corpSyncAll(corpId))
    const actionRef = useRef<ActionType>();
    let timeRef = useRef<any>()
    const auth = () => {
        CorpPreAuth.run().then(res => {
            if (res.data) {
                setCodeOpen(res.data)
                setCodeState("active")
                run()
            }
        })
    }
    const run = () => {
        if (timeRef.current) {
            clearInterval(timeRef.current)
        }
        timeRef.current = setInterval(() => {
            setCodeState("expired")
        }, 1000 * 60 * 10)
    }
    const sync = (corpId: any) => {
        CorpSyncAll.run(corpId).then(res => {
            if (res.code === 200) {
                message.success("同步成功！")
                actionRef?.current?.reload()
            }
        })
    }
    return <PageContainer >
        <ProTable<any, any>
            actionRef={actionRef}
            headerTitle={"企微列表"}
            rowKey={(r) => r.id}
            search={{
                labelWidth: 90,
            }}
            scroll={{ x: true }}
            request={async (params) => {
                return await getList.run(params)
            }}
            columns={columns(sync)}
            toolBarRender={() => [
                <Button type="primary" onClick={auth} ><PlusOutlined />新增企微</Button>,
            ]}
        />
        <Modal
            footer={null}
            open={!!codeOpen}
            onCancel={() => {
                setCodeOpen(""); clearInterval(timeRef.current)
            }}
            maskClosable={false}
            width={350}
            title="企微管理员扫码授权">
            <QRCode size={300} type="svg" value={codeOpen} onRefresh={auth} status={codeState} />
        </Modal>
    </PageContainer>

}
export default Page