import { ProFormColumnsType } from "@ant-design/pro-components";
import { useModel } from "@umijs/max";

function formConfig(): ProFormColumnsType<{
}>[] {
    let { getEnum } = useModel("global")
    return [
        {
            valueType: 'digit',
            dataIndex: "regPayIntervalTime",
            title: "注册充值回传的最大间隔时间",
            tooltip: "（超时不回传）",
            colProps: { span: 12 },
            formItemProps: {
                style: { marginBottom: 10 },
                rules: [
                    {
                        required: true,
                        message: '此项为必填项',
                    },
                ],
            },
            fieldProps: {
                placeholder: '请输入数字',
                style: { width: "70%" },
                addonAfter: "分钟"
            },
        },
        {
            valueType: 'digit',
            dataIndex: "maxBackCountOfUser",
            title: "单用户最大回传订单数",
            colProps: { span: 12 },
            formItemProps: {
                style: { marginBottom: 10 },
                rules: [
                    {
                        required: true,
                        message: '此项为必填项',
                    },
                ],
            },
            fieldProps: {
                placeholder: '请输入数字',
                style: { width: "70%" },
            },
        },
        {
            valueType: 'radioButton',
            dataIndex: "backUnit",
            title: "回传类型",
            initialValue: 1,
            formItemProps: {
                style: { marginBottom: 10 },
                rules: [
                    {
                        required: true,
                        message: '此项为必填项',
                    },
                ],
            },
            fieldProps: {
                buttonStyle: 'solid'
            },
            valueEnum: getEnum("CALLBACK_TYPE", "map")
        },
        {
            valueType: 'radioButton',
            dataIndex: "vipOrderBackType",
            title: "VIP回传策略",
            colProps: { span: 12 },
            initialValue: 1,
            formItemProps: {
                style: { marginBottom: 10 },
                rules: [
                    {
                        required: true,
                        message: '此项为必填项',
                    },
                ],
            },
            fieldProps: {
                buttonStyle: 'solid'
            },
            valueEnum: getEnum("VIP_CALLBACK", "map")
        },
        {
            valueType: 'radioButton',
            dataIndex: "markUpOrder",
            title: "是否补单",
            initialValue: false,
            colProps: { span: 4 },
            formItemProps: {
                style: { marginBottom: 10 },
                rules: [
                    {
                        required: true,
                        message: '此项为必填项',
                    },
                ],
            },
            fieldProps: {
                buttonStyle: 'solid'
            },
            valueEnum: new Map([true, false].map(key => [key, key ? "是" : "否"]))
        },
        {
            valueType: 'dependency',
            name: ["backUnit", "markUpOrder"],
            columns({ backUnit, markUpOrder }) {
                return [
                    // 首单
                    {
                        valueType: 'group',
                        colProps: { span: 24 },
                        columns: [
                            {
                                valueType: 'divider',
                                fieldProps: {
                                    children: backUnit === 1 ? "首单" : "首日",
                                    orientation: "left"
                                }
                            },
                            {
                                dataIndex: 'firstBackRate',
                                valueType: 'formList',
                                fieldProps: {
                                    creatorButtonProps: {
                                        creatorButtonText: "添加一个档位配置",
                                    },
                                    alwaysShowItemLabel: true,//全部展示title
                                },
                                colProps: {
                                    span: 24
                                },
                                columns: [
                                    {
                                        valueType: 'group',
                                        colProps: {
                                            span: 24
                                        },
                                        columns: [
                                            {
                                                dataIndex: 'minAmount',
                                                valueType: 'digit',
                                                title: "最小金额",
                                                tooltip: "最小金额（大于等于）",
                                                fieldProps: {
                                                    placeholder: "最小金额",
                                                    style: { width: "100%" },
                                                },
                                                colProps: { span: 5 },
                                                formItemProps: {
                                                    style: { marginBottom: 10 },
                                                    rules: [
                                                        {
                                                            required: true,
                                                            message: '此项为必填项',
                                                        },
                                                    ],
                                                },
                                            },
                                            {
                                                dataIndex: 'maxAmount',
                                                valueType: 'digit',
                                                title: "最大金额",
                                                tooltip: "最大金额（小于）",
                                                colProps: { span: 5 },
                                                fieldProps: {
                                                    placeholder: "最大金额",
                                                    style: { width: "100%" },
                                                },
                                                formItemProps: {
                                                    style: { marginBottom: 10 },
                                                    rules: [
                                                        {
                                                            required: true,
                                                            message: '此项为必填项',
                                                        },
                                                    ],
                                                },
                                            },
                                            {
                                                dataIndex: 'backType',
                                                valueType: 'radioButton',
                                                title: "回传方式",
                                                colProps: { span: 5, offset: 1 },
                                                initialValue: 1,
                                                formItemProps: {
                                                    style: { marginBottom: 10 },
                                                    rules: [
                                                        {
                                                            required: true,
                                                            message: '此项为必填项',
                                                        },
                                                    ],
                                                },
                                                fieldProps: {
                                                    buttonStyle: 'solid'
                                                },
                                                valueEnum: new Map(["比例", "概率"]?.map((text, index) => [index, text])),
                                            },
                                            {
                                                valueType: "dependency",
                                                name: ["backType"],
                                                columns(values) {
                                                    let { backType } = values
                                                    return [
                                                        {
                                                            valueType: 'digitRange',
                                                            dataIndex: 'backRate',
                                                            title: "回传比例",
                                                            colProps: { span: 7 },
                                                            preserve: false,
                                                            convertValue: (value) => {
                                                                return typeof value === "string" ? value?.split(":") : Array.isArray(value) ? value : []
                                                            },
                                                            hideInForm: backType === 1,
                                                            formItemProps: {
                                                                style: { marginBottom: 10 },
                                                                rules: [
                                                                    {
                                                                        required: true,
                                                                        message: '此项为必填项',
                                                                    },
                                                                ],
                                                            },
                                                        },
                                                        {
                                                            valueType: 'select',
                                                            dataIndex: "backRate",
                                                            title: "回传概率",
                                                            colProps: { span: 7 },
                                                            preserve: true,
                                                            hideInForm: backType !== 1,
                                                            convertValue: (value) => {
                                                                console.log(value)
                                                                let v: any = String(value).includes(":") || !value ? 0 : Number(value)
                                                                return v
                                                            },
                                                            formItemProps: {
                                                                style: { marginBottom: 10 },
                                                                rules: [
                                                                    {
                                                                        required: true,
                                                                        message: '此项为必填项',
                                                                    },
                                                                ],
                                                            },
                                                            valueEnum: new Map([0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10]?.map((text) => [text * 10, text * 10 + "%"]))
                                                        },
                                                    ]
                                                },
                                            }
                                        ]
                                    }
                                ]
                            },
                        ]
                    },
                    // 次单
                    {
                        valueType: 'group',
                        colProps: { span: 24 },
                        columns: [
                            {
                                valueType: 'divider',
                                fieldProps: {
                                    children: backUnit === 1 ? "次单" : "次日",
                                    orientation: "left"
                                }
                            },
                            {
                                dataIndex: 'otherBackRate',
                                valueType: 'formList',
                                fieldProps: {
                                    creatorButtonProps: {
                                        creatorButtonText: "添加一个档位配置",
                                    },
                                    alwaysShowItemLabel: true,//全部展示title
                                },
                                colProps: {
                                    span: 24
                                },
                                columns: [
                                    {
                                        valueType: 'group',
                                        colProps: {
                                            span: 24
                                        },
                                        columns: [
                                            {
                                                dataIndex: 'minAmount',
                                                valueType: 'digit',
                                                title: "最小金额",
                                                tooltip: "最小金额（大于等于）",
                                                fieldProps: {
                                                    placeholder: "最小金额",
                                                    style: { width: "100%" },
                                                },
                                                colProps: { span: 5 },
                                                formItemProps: {
                                                    style: { marginBottom: 10 },
                                                    rules: [
                                                        {
                                                            required: true,
                                                            message: '此项为必填项',
                                                        },
                                                    ],
                                                },
                                            },
                                            {
                                                dataIndex: 'maxAmount',
                                                valueType: 'digit',
                                                title: "最大金额",
                                                tooltip: "最大金额（小于）",
                                                colProps: { span: 5 },
                                                fieldProps: {
                                                    placeholder: "最大金额",
                                                    style: { width: "100%" },
                                                },
                                                formItemProps: {
                                                    style: { marginBottom: 10 },
                                                    rules: [
                                                        {
                                                            required: true,
                                                            message: '此项为必填项',
                                                        },
                                                    ],
                                                },
                                            },
                                            {
                                                dataIndex: 'backType',
                                                valueType: 'radioButton',
                                                title: "回传方式",
                                                colProps: { span: 5, offset: 1 },
                                                initialValue: 1,
                                                formItemProps: {
                                                    style: { marginBottom: 10 },
                                                    rules: [
                                                        {
                                                            required: true,
                                                            message: '此项为必填项',
                                                        },
                                                    ],
                                                },
                                                fieldProps: {
                                                    buttonStyle: 'solid'
                                                },
                                                valueEnum: new Map(["比例", "概率"]?.map((text, index) => [index, text])),
                                            },
                                            {
                                                valueType: "dependency",
                                                name: ["backType"],
                                                columns(values) {
                                                    let { backType } = values
                                                    return [
                                                        {
                                                            valueType: 'digitRange',
                                                            dataIndex: 'backRate',
                                                            title: "回传比例",
                                                            colProps: { span: 7 },
                                                            preserve: false,
                                                            convertValue: (value) => {
                                                                return typeof value === "string" ? value?.split(":") : Array.isArray(value) ? value : []
                                                            },
                                                            hideInForm: backType === 1,
                                                            formItemProps: {
                                                                style: { marginBottom: 10 },
                                                                rules: [
                                                                    {
                                                                        required: true,
                                                                        message: '此项为必填项',
                                                                    },
                                                                ],
                                                            },
                                                        },
                                                        {
                                                            valueType: 'select',
                                                            dataIndex: "backRate",
                                                            title: "回传概率",
                                                            colProps: { span: 7 },
                                                            preserve: true,
                                                            hideInForm: backType !== 1,
                                                            convertValue: (value) => {
                                                                let v: any = typeof value === "number" ? value : 0
                                                                return v
                                                            },
                                                            formItemProps: {
                                                                style: { marginBottom: 10 },
                                                                rules: [
                                                                    {
                                                                        required: true,
                                                                        message: '此项为必填项',
                                                                    },
                                                                ],
                                                            },
                                                            valueEnum: new Map([0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10]?.map((text) => [text * 10, text * 10 + "%"]))
                                                        },
                                                    ]
                                                },
                                            }
                                        ]
                                    }
                                ]
                            },
                        ]
                    },
                    // 降档
                    {
                        valueType: 'group',
                        colProps: { span: 24 },
                        columns: [
                            {
                                valueType: 'divider',
                                fieldProps: {
                                    children: "降档",
                                    orientation: "left"
                                }
                            },
                            {
                                dataIndex: 'downLevel',
                                valueType: 'formList',
                                fieldProps: {
                                    creatorButtonProps: {
                                        creatorButtonText: "添加一个档位配置",
                                    },
                                    alwaysShowItemLabel: true,//全部展示title
                                },
                                colProps: {
                                    span: 24
                                },
                                columns: [
                                    {
                                        valueType: 'group',
                                        colProps: {
                                            span: 24
                                        },
                                        columns: [
                                            {
                                                dataIndex: 'minMoney',
                                                valueType: 'digit',
                                                title: "最小金额",
                                                fieldProps: {
                                                    placeholder: "最小金额",
                                                    style: { width: "100%" },
                                                },
                                                colProps: { span: 8 },
                                                formItemProps: {
                                                    style: { marginBottom: 10 },
                                                    rules: [
                                                        {
                                                            required: true,
                                                            message: '此项为必填项',
                                                        },
                                                    ],
                                                },
                                            },
                                            {
                                                dataIndex: 'maxMoney',
                                                valueType: 'digit',
                                                title: "最大金额",
                                                colProps: { span: 8 },
                                                fieldProps: {
                                                    placeholder: "最大金额",
                                                    style: { width: "100%" },
                                                },
                                                formItemProps: {
                                                    style: { marginBottom: 10 },
                                                    rules: [
                                                        {
                                                            required: true,
                                                            message: '此项为必填项',
                                                        },
                                                    ],
                                                },
                                            },
                                            {
                                                dataIndex: 'backMoney',
                                                valueType: 'digit',
                                                title: "回传金额",
                                                colProps: { span: 8 },
                                                fieldProps: {
                                                    placeholder: "回传金额",
                                                    style: { width: "100%" },
                                                },
                                                formItemProps: {
                                                    style: { marginBottom: 10 },
                                                    rules: [
                                                        {
                                                            required: true,
                                                            message: '此项为必填项',
                                                        },
                                                    ],
                                                },
                                            },
                                        ]
                                    }
                                ]
                            },
                        ]
                    },
                    // 拆单
                    {
                        valueType: 'group',
                        colProps: { span: 24 },
                        columns: [
                            {
                                valueType: 'divider',
                                fieldProps: {
                                    children: "拆单",
                                    orientation: "left"
                                }
                            },
                            {
                                dataIndex: 'splitStrategy',
                                valueType: 'formList',
                                fieldProps: {
                                    creatorButtonProps: {
                                        creatorButtonText: "添加一个档位配置",
                                    },
                                    alwaysShowItemLabel: true,//全部展示title
                                },
                                colProps: {
                                    span: 24
                                },
                                columns: [
                                    {
                                        valueType: 'group',
                                        colProps: {
                                            span: 24
                                        },
                                        columns: [
                                            {
                                                dataIndex: 'payMoney',
                                                valueType: 'digit',
                                                title: "支付金额",
                                                fieldProps: {
                                                    placeholder: "支付金额",
                                                    style: { width: "100%" },
                                                },
                                                colProps: { span: 6 },
                                                formItemProps: {
                                                    style: { marginBottom: 10 },
                                                    rules: [
                                                        {
                                                            required: true,
                                                            message: '此项为必填项',
                                                        },
                                                    ],
                                                },
                                            },
                                            {
                                                valueType: 'digit',
                                                dataIndex: "splitList",
                                                title: "拆分金额",
                                                colProps: { span: 6 },
                                                formItemProps: {
                                                    style: { marginBottom: 10 },
                                                    rules: [
                                                        {
                                                            required: true,
                                                            message: '此项为必填项',
                                                        },
                                                    ],
                                                },
                                                fieldProps: {
                                                    placeholder: '请输入数字',
                                                    style: { width: "100%" },
                                                    addonAfter: "份"
                                                },
                                            },
                                            {
                                                valueType: 'digit',
                                                dataIndex: "betweenMinuteMin",
                                                title: "最小回传间隔时间",
                                                colProps: { span: 6 },
                                                formItemProps: {
                                                    style: { marginBottom: 10 },
                                                    rules: [
                                                        {
                                                            required: true,
                                                            message: '此项为必填项',
                                                        },
                                                    ],
                                                },
                                                fieldProps: {
                                                    placeholder: '请输入数字',
                                                    style: { width: "100%" },
                                                    addonAfter: "分钟"
                                                },
                                            },
                                            {
                                                valueType: 'digit',
                                                dataIndex: "betweenMinuteMax",
                                                title: "最大回传间隔时间",
                                                colProps: { span: 6 },
                                                formItemProps: {
                                                    style: { marginBottom: 10 },
                                                    rules: [
                                                        {
                                                            required: true,
                                                            message: '此项为必填项',
                                                        },
                                                    ],
                                                },
                                                fieldProps: {
                                                    placeholder: '请输入数字',
                                                    style: { width: "100%" },
                                                    addonAfter: "分钟"
                                                },
                                            },
                                        ]
                                    }
                                ]
                            },
                        ]
                    },
                    // 补单
                    {
                        valueType: 'group',
                        hideInForm: !markUpOrder,
                        colProps: { span: 24 },
                        columns: [
                            {
                                valueType: 'divider',
                                fieldProps: {
                                    children: "补单",
                                    orientation: "left"
                                }
                            },
                            {
                                dataIndex: 'markUpBackRate',
                                valueType: 'formList',
                                fieldProps: {
                                    creatorButtonProps: {
                                        creatorButtonText: "添加一个档位配置",
                                    },
                                    alwaysShowItemLabel: true,//全部展示title
                                },
                                colProps: {
                                    span: 24
                                },
                                columns: [
                                    {
                                        valueType: 'group',
                                        colProps: {
                                            span: 24
                                        },
                                        columns: [
                                            {
                                                dataIndex: 'minAmount',
                                                valueType: 'digit',
                                                title: "最小金额",
                                                tooltip: "最小金额（大于等于）",
                                                fieldProps: {
                                                    placeholder: "最小金额",
                                                    style: { width: "100%" },
                                                },
                                                colProps: { span: 5 },
                                                formItemProps: {
                                                    style: { marginBottom: 10 },
                                                    rules: [
                                                        {
                                                            required: true,
                                                            message: '此项为必填项',
                                                        },
                                                    ],
                                                },
                                            },
                                            {
                                                dataIndex: 'maxAmount',
                                                valueType: 'digit',
                                                title: "最大金额",
                                                tooltip: "最大金额（小于）",
                                                colProps: { span: 5 },
                                                fieldProps: {
                                                    placeholder: "最大金额",
                                                    style: { width: "100%" },
                                                },
                                                formItemProps: {
                                                    style: { marginBottom: 10 },
                                                    rules: [
                                                        {
                                                            required: true,
                                                            message: '此项为必填项',
                                                        },
                                                    ],
                                                },
                                            },
                                            {
                                                dataIndex: 'backType',
                                                valueType: 'radioButton',
                                                title: "回传方式",
                                                colProps: { span: 5, offset: 1 },
                                                initialValue: 1,
                                                formItemProps: {
                                                    style: { marginBottom: 10 },
                                                    rules: [
                                                        {
                                                            required: true,
                                                            message: '此项为必填项',
                                                        },
                                                    ],
                                                },
                                                fieldProps: {
                                                    buttonStyle: 'solid'
                                                },
                                                valueEnum: new Map(["比例", "概率"]?.map((text, index) => [index, text])),
                                            },
                                            {
                                                valueType: "dependency",
                                                name: ["backType"],
                                                columns(values) {
                                                    let { backType } = values
                                                    return [
                                                        {
                                                            valueType: 'digitRange',
                                                            dataIndex: 'backRate',
                                                            title: "回传比例",
                                                            colProps: { span: 7 },
                                                            preserve: false,
                                                            convertValue: (value) => {
                                                                return typeof value === "string" ? value?.split(":") : Array.isArray(value) ? value : []
                                                            },
                                                            hideInForm: backType === 1,
                                                            formItemProps: {
                                                                style: { marginBottom: 10 },
                                                                rules: [
                                                                    {
                                                                        required: true,
                                                                        message: '此项为必填项',
                                                                    },
                                                                ],
                                                            },
                                                        },
                                                        {
                                                            valueType: 'select',
                                                            dataIndex: "backRate",
                                                            title: "回传概率",
                                                            colProps: { span: 7 },
                                                            preserve: true,
                                                            hideInForm: backType !== 1,
                                                            convertValue: (value) => {
                                                                let v: any = typeof value === "number" ? value : 0
                                                                return v
                                                            },
                                                            formItemProps: {
                                                                style: { marginBottom: 10 },
                                                                rules: [
                                                                    {
                                                                        required: true,
                                                                        message: '此项为必填项',
                                                                    },
                                                                ],
                                                            },
                                                            valueEnum: new Map([0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10]?.map((text) => [text * 10, text * 10 + "%"]))
                                                        },
                                                    ]
                                                },
                                            }
                                        ]
                                    }
                                ]
                            },
                        ]
                    },
                ]
            },
        },
    ]
}

export default formConfig