import UploadImg from "@/components/uploadImg";
import { ArrowDownOutlined, ArrowUpOutlined } from "@ant-design/icons";
import { ProFormColumnsType, ProFormInstance } from "@ant-design/pro-components";
import styles from './index.less'
import { Select, Tooltip } from "antd";
import BookSelect from "@/components/bookSelect";
import BookSelectDrawer from "@/components/bookSelect/drawer";
// banners
export function bannersConfig(pageList: any[]): ProFormColumnsType<any>[] {
    return [
        {
            valueType: 'formList',
            dataIndex: "configs",
            colProps: {
                span: 24
            },
            fieldProps: {
                creatorButtonProps: {
                    creatorButtonText: "添加一个Banner",
                },
                alwaysShowItemLabel: true,//全部展示title
                actionRender: (field: any, action: any, defaultActionDom: any, count: any) => {//自定义按钮
                    return [...defaultActionDom,
                    field.name < count - 1 && <Tooltip title="向下移动" key={`move-down-${field.name}`}><ArrowDownOutlined className={styles.upDownBtn} onClick={() => { action.move(field.name + 1, field.name) }} /></Tooltip>,
                    field.name > 0 && <Tooltip title="向上移动" key={`move-up-${field.name}`}><ArrowUpOutlined className={styles.upDownBtn} onClick={() => { action.move(field.name - 1, field.name) }} /></Tooltip>]
                }
            },
            columns: [
                {
                    valueType: 'group',
                    colProps: {
                        span: 24
                    },
                    columns: [
                        {
                            title: 'banner类型',
                            dataIndex: 'bannerType',
                            valueType: 'radio',
                            initialValue:1,
                            convertValue: (value) => {
                                return value?.toString()
                            },
                            valueEnum: { 0: { text: "小说" }, 1: { text: "活动" } },
                            colProps: {
                                span: 24
                            },
                            formItemProps: {
                                style: { marginBottom: 10 },
                                initialValue:"0",
                                rules: [
                                    {
                                        required: true,
                                        message: '此项为必填项',
                                    },
                                ],
                            }
                        },
                        {
                            valueType: 'dependency',
                            name: ['bannerType'],
                            columns: ({ bannerType }) => {
                                return [
                                    {
                                        dataIndex: "bookId",
                                        title: '小说',
                                        hideInForm: bannerType == 1,
                                        formItemProps: {
                                            style: { marginBottom: 10 },
                                            rules: [
                                                {
                                                    required: true,
                                                    message: '此项为必填项',
                                                },
                                            ],
                                        },
                                        colProps: {
                                            span: 24
                                        },
                                        renderFormItem(schema, config, form, action) {
                                            return <BookSelectDrawer />
                                        },
                                    },
                                    {
                                        valueType: 'select',
                                        dataIndex: "activityPagePath",
                                        title: '活动页面',
                                        colProps: {
                                            span: 24
                                        },
                                        fieldProps: {
                                            style: { width: '100%'  },
                                            showSearch: true,
                                            placeholder: '请选择活动页面'
                                        },
                                        hideInForm: bannerType != 1,
                                        formItemProps: {
                                            style: { marginBottom: 10 },
                                            rules: [
                                                {
                                                    required: true,
                                                    message: '此项为必填项',
                                                },
                                            ],
                                        },
                                        valueEnum: new Map(pageList?.map(({ pagePath, pageName }) => [pagePath, pageName])),
                                    }
                                ]
                            }
                        },
                        {
                            title: 'banner图片',
                            dataIndex: 'bannerImage',
                            colProps: {
                                span: 24,
                            },
                            formItemProps: {
                                rules: [
                                    {
                                        required: true,
                                        message: '此项为必填项',
                                    },
                                ],
                            },
                            renderFormItem: () => {
                                return (
                                    <UploadImg
                                        size={{
                                            width: 690,
                                            height: 248,
                                            evalW: '!=',
                                            evalH: '!=',
                                            msg: '需要图片大小690*248',
                                        }}
                                        isEdit={true}
                                        type="image"
                                        isCropper
                                    />
                                );
                            },
                        },
                        {
                            valueType: 'divider',
                        }
                    ]
                }
            ]
        },

    ]
}
// 今日热书
export function hotBooksConfig(): ProFormColumnsType<any>[] {
    return [
        {
            title: '标题名称',
            dataIndex: 'componentName',
            colProps: {
                span: 12
            },
            fieldProps: {
                allowClear: true,
                placeholder: '请输入名称'
            },
            formItemProps: {
                style: { marginBottom: 10 },
            }
        },
        {
            title: '显示右侧按钮',
            dataIndex: 'showRightButton',
            valueType: "radio",
            valueEnum: new Map([{ value: true, text: "是" }, { value: false, text: "否" }].map(item => [item.value, item.text])),
            formItemProps: {
                style: { marginBottom: 10 },
            },
            colProps: {
                span: 12
            },
        },
        {
            valueType: 'divider',
        },
        {
            valueType: 'formList',
            dataIndex: "configs",
            colProps: {
                span: 24
            },
            fieldProps: {
                max: 5,
                min: 5,
                creatorButtonProps: {
                    creatorButtonText: "添加一本书",
                },
                alwaysShowItemLabel: true,//全部展示title
                actionRender: (field: any, action: any, defaultActionDom: any, count: any) => {//自定义按钮
                    return [...defaultActionDom,
                    field.name < count - 1 && <Tooltip title="向下移动" key={`move-down-${field.name}`}><ArrowDownOutlined className={styles.upDownBtn} onClick={() => { action.move(field.name + 1, field.name) }} /></Tooltip>,
                    field.name > 0 && <Tooltip title="向上移动" key={`move-up-${field.name}`}><ArrowUpOutlined className={styles.upDownBtn} onClick={() => { action.move(field.name - 1, field.name) }} /></Tooltip>]
                }
            },
            columns: [
                {
                    valueType: 'group',
                    colProps: {
                        span: 24
                    },
                    columns: [
                        {
                            dataIndex: "bookId",
                            title: '小说',
                            colProps: {
                                span: 24
                            },
                            formItemProps: {
                                style: { marginBottom: 10 },
                                rules: [
                                    {
                                        required: true,
                                        message: '此项为必填项',
                                    },
                                ],
                            },
                            renderFormItem(schema, config, form, action) {
                                // return <BookSelect />
                                return <BookSelectDrawer />
                            },
                        },
                        {
                            valueType: 'divider',
                        }
                    ]
                }
            ]
        },

    ]
}
// 热门分类
export function hotCategoryConfig(tags: any[], formRef: React.MutableRefObject<ProFormInstance | undefined>): ProFormColumnsType<any>[] {
    return [
        {
            title: '标题名称',
            dataIndex: 'componentName',
            colProps: {
                span: 12
            },
            fieldProps: {
                allowClear: true,
                placeholder: '请输入名称'
            },
            formItemProps: {
                style: { marginBottom: 10 },
            }
        },
        {
            title: '显示右侧按钮',
            dataIndex: 'showRightButton',
            valueType: "radio",
            valueEnum: new Map([{ value: true, text: "是" }, { value: false, text: "否" }].map(item => [item.value, item.text])),
            formItemProps: {
                style: { marginBottom: 10 },
            },
            colProps: {
                span: 12
            },
        },
        {
            valueType: 'divider',
        },
        {
            valueType: 'formList',
            dataIndex: "configs",
            colProps: {
                span: 24
            },
            fieldProps: {
                creatorButtonProps: {
                    creatorButtonText: "添加一个标签",
                },
                alwaysShowItemLabel: true,//全部展示title
                actionRender: (field: any, action: any, defaultActionDom: any, count: any) => {//自定义按钮
                    return [...defaultActionDom,
                    field.name < count - 1 && <Tooltip title="向下移动" key={`move-down-${field.name}`}><ArrowDownOutlined className={styles.upDownBtn} onClick={() => { action.move(field.name + 1, field.name) }} /></Tooltip>,
                    field.name > 0 && <Tooltip title="向上移动" key={`move-up-${field.name}`}><ArrowUpOutlined className={styles.upDownBtn} onClick={() => { action.move(field.name - 1, field.name) }} /></Tooltip>]
                }
            },
            columns: [
                {
                    valueType: 'dependency',
                    name: ["configs"],
                    columns(values) {
                        let configs = formRef.current?.getFieldValue("configs")
                        return [{
                            valueType: 'group',
                            colProps: {
                                span: 24
                            },
                            columns: [
                                {
                                    dataIndex: "categoryId",
                                    title: '标签',
                                    valueType: 'select',
                                    colProps: {
                                        span: 12
                                    },
                                    convertValue: (value) => {
                                        return value?.toString()
                                    },
                                    formItemProps: {
                                        style: { marginBottom: 10 },
                                        rules: [
                                            {
                                                required: true,
                                                message: '此项为必填项',
                                            },
                                        ],
                                    },
                                    fieldProps: {
                                        showSearch: true
                                    },
                                    valueEnum: () => {
                                        return tags?.reduce((acc, current) => {
                                            acc[current.id] = { text: current.name, disabled: configs?.some((item: { categoryId: any; }) => item.categoryId == current.id) ? true : false };//
                                            return acc;
                                        }, {});
                                    }
                                },
                                {
                                    valueType: 'divider',
                                }
                            ]
                        }]
                    },
                }
            ]
        },

    ]
}
// 热门推荐
export function hotRecConfig(): ProFormColumnsType<any>[] {
    return [
        {
            title: '标题名称',
            dataIndex: 'componentName',
            colProps: {
                span: 12
            },
            fieldProps: {
                allowClear: true,
                placeholder: '请输入名称'
            },
            formItemProps: {
                style: { marginBottom: 10 },
            }
        },
        {
            title: '显示右侧按钮',
            dataIndex: 'showRightButton',
            valueType: "radio",
            valueEnum: new Map([{ value: true, text: "是" }, { value: false, text: "否" }].map(item => [item.value, item.text])),
            formItemProps: {
                style: { marginBottom: 10 },
            },
            colProps: {
                span: 12
            },
        },
        {
            valueType: 'divider',
        },
        {
            valueType: 'formList',
            dataIndex: "configs",
            colProps: {
                span: 24
            },
            fieldProps: {
                max: 3,
                min: 3,
                creatorButtonProps: {
                    creatorButtonText: "添加一本书",
                },
                alwaysShowItemLabel: true,//全部展示title
                actionRender: (field: any, action: any, defaultActionDom: any, count: any) => {//自定义按钮
                    return [...defaultActionDom,
                    field.name < count - 1 && <Tooltip title="向下移动" key={`move-down-${field.name}`}><ArrowDownOutlined className={styles.upDownBtn} onClick={() => { action.move(field.name + 1, field.name) }} /></Tooltip>,
                    field.name > 0 && <Tooltip title="向上移动" key={`move-up-${field.name}`}><ArrowUpOutlined className={styles.upDownBtn} onClick={() => { action.move(field.name - 1, field.name) }} /></Tooltip>]
                }
            },
            columns: [
                {
                    valueType: 'group',
                    colProps: {
                        span: 24
                    },
                    columns: [
                        {
                            dataIndex: "bookId",
                            title: '小说',
                            colProps: {
                                span: 24
                            },
                            formItemProps: {
                                style: { marginBottom: 10 },
                                rules: [
                                    {
                                        required: true,
                                        message: '此项为必填项',
                                    },
                                ],
                            },
                            renderFormItem(schema, config, form, action) {
                                // return <BookSelect />
                                return <BookSelectDrawer />
                            },
                        },
                        {
                            valueType: 'divider',
                        }
                    ]
                }
            ]
        },

    ]
}
// 重磅新书
export function newBooksConfig(): ProFormColumnsType<any>[] {
    return [
        {
            title: '标题名称',
            dataIndex: 'componentName',
            colProps: {
                span: 12
            },
            fieldProps: {
                allowClear: true,
                placeholder: '请输入名称'
            },
            formItemProps: {
                style: { marginBottom: 10 },
            }
        },
        {
            title: '显示右侧按钮',
            dataIndex: 'showRightButton',
            valueType: "radio",
            valueEnum: new Map([{ value: true, text: "是" }, { value: false, text: "否" }].map(item => [item.value, item.text])),
            formItemProps: {
                style: { marginBottom: 10 },
            },
            colProps: {
                span: 12
            },
        },
        {
            valueType: 'divider',
        },
        {
            valueType: 'formList',
            dataIndex: "configs",
            colProps: {
                span: 24
            },
            fieldProps: {
                max: 3,
                min: 3,
                creatorButtonProps: {
                    creatorButtonText: "添加一本书",
                },
                alwaysShowItemLabel: true,//全部展示title
                actionRender: (field: any, action: any, defaultActionDom: any, count: any) => {//自定义按钮
                    return [...defaultActionDom,
                    field.name < count - 1 && <Tooltip title="向下移动" key={`move-down-${field.name}`}><ArrowDownOutlined className={styles.upDownBtn} onClick={() => { action.move(field.name + 1, field.name) }} /></Tooltip>,
                    field.name > 0 && <Tooltip title="向上移动" key={`move-up-${field.name}`}><ArrowUpOutlined className={styles.upDownBtn} onClick={() => { action.move(field.name - 1, field.name) }} /></Tooltip>]
                }
            },
            columns: [
                {
                    valueType: 'group',
                    colProps: {
                        span: 24
                    },
                    columns: [
                        {
                            dataIndex: "bookId",
                            title: '小说',
                            colProps: {
                                span: 24
                            },
                            formItemProps: {
                                style: { marginBottom: 10 },
                                rules: [
                                    {
                                        required: true,
                                        message: '此项为必填项',
                                    },
                                ],
                            },
                            renderFormItem(schema, config, form, action) {
                                // return <BookSelect />
                                return <BookSelectDrawer />
                            },
                        },
                        {
                            valueType: 'divider',
                        }
                    ]
                }
            ]
        },

    ]
}
// 口碑佳作
export function bestReviewsConfig(): ProFormColumnsType<any>[] {
    return [
        {
            title: '标题名称',
            dataIndex: 'componentName',
            colProps: {
                span: 12
            },
            fieldProps: {
                allowClear: true,
                placeholder: '请输入名称'
            },
            formItemProps: {
                style: { marginBottom: 10 },
            }
        },
        {
            title: '显示右侧按钮',
            dataIndex: 'showRightButton',
            valueType: "radio",
            valueEnum: new Map([{ value: true, text: "是" }, { value: false, text: "否" }].map(item => [item.value, item.text])),
            formItemProps: {
                style: { marginBottom: 10 },
            },
            colProps: {
                span: 12
            },
        },
        {
            valueType: 'divider',
        },
        {
            valueType: 'formList',
            dataIndex: "configs",
            colProps: {
                span: 24
            },
            fieldProps: {
                max: 4,
                min: 4,
                creatorButtonProps: {
                    creatorButtonText: "添加一本书",
                },
                alwaysShowItemLabel: true,//全部展示title
                actionRender: (field: any, action: any, defaultActionDom: any, count: any) => {//自定义按钮
                    return [...defaultActionDom,
                    field.name < count - 1 && <Tooltip title="向下移动" key={`move-down-${field.name}`}><ArrowDownOutlined className={styles.upDownBtn} onClick={() => { action.move(field.name + 1, field.name) }} /></Tooltip>,
                    field.name > 0 && <Tooltip title="向上移动" key={`move-up-${field.name}`}><ArrowUpOutlined className={styles.upDownBtn} onClick={() => { action.move(field.name - 1, field.name) }} /></Tooltip>]
                }
            },
            columns: [
                {
                    valueType: 'group',
                    colProps: {
                        span: 24
                    },
                    columns: [
                        {
                            dataIndex: "bookId",
                            title: '小说',
                            colProps: {
                                span: 24
                            },
                            formItemProps: {
                                style: { marginBottom: 10 },
                                rules: [
                                    {
                                        required: true,
                                        message: '此项为必填项',
                                    },
                                ],
                            },
                            renderFormItem(schema, config, form, action) {
                                // return <BookSelect />
                                return <BookSelectDrawer />
                            },
                        },
                        {
                            valueType: 'divider',
                        }
                    ]
                }
            ]
        },

    ]
}
// 经典热书
export function classicBooksConfig(): ProFormColumnsType<any>[] {
    return [
        {
            title: '标题名称',
            dataIndex: 'componentName',
            colProps: {
                span: 12
            },
            fieldProps: {
                allowClear: true,
                placeholder: '请输入名称'
            },
            formItemProps: {
                style: { marginBottom: 10 },
            }
        },
        {
            title: '显示右侧按钮',
            dataIndex: 'showRightButton',
            valueType: "radio",
            valueEnum: new Map([{ value: true, text: "是" }, { value: false, text: "否" }].map(item => [item.value, item.text])),
            formItemProps: {
                style: { marginBottom: 10 },
            },
            colProps: {
                span: 12
            },
        },
        {
            valueType: 'divider',
        },
        {
            valueType: 'formList',
            dataIndex: "configs",
            colProps: {
                span: 24
            },
            fieldProps: {
                max: 8,
                min: 8,
                creatorButtonProps: {
                    creatorButtonText: "添加一本书",
                },
                alwaysShowItemLabel: true,//全部展示title
                actionRender: (field: any, action: any, defaultActionDom: any, count: any) => {//自定义按钮
                    return [...defaultActionDom,
                    field.name < count - 1 && <Tooltip title="向下移动" key={`move-down-${field.name}`}><ArrowDownOutlined className={styles.upDownBtn} onClick={() => { action.move(field.name + 1, field.name) }} /></Tooltip>,
                    field.name > 0 && <Tooltip title="向上移动" key={`move-up-${field.name}`}><ArrowUpOutlined className={styles.upDownBtn} onClick={() => { action.move(field.name - 1, field.name) }} /></Tooltip>]
                }
            },
            columns: [
                {
                    valueType: 'group',
                    colProps: {
                        span: 24
                    },
                    columns: [
                        {
                            dataIndex: "bookId",
                            title: '小说',
                            colProps: {
                                span: 24
                            },
                            formItemProps: {
                                style: { marginBottom: 10 },
                                rules: [
                                    {
                                        required: true,
                                        message: '此项为必填项',
                                    },
                                ],
                            },
                            renderFormItem(schema, config, form, action) {
                                // return <BookSelect />
                                return <BookSelectDrawer />
                            },
                        },
                        {
                            valueType: 'divider',
                        }
                    ]
                }
            ]
        },

    ]
}
// 必看好书
export function bestBooksConfig(): ProFormColumnsType<any>[] {
    return [
        {
            title: '标题名称',
            dataIndex: 'componentName',
            colProps: {
                span: 12
            },
            fieldProps: {
                allowClear: true,
                placeholder: '请输入名称'
            },
            formItemProps: {
                style: { marginBottom: 10 },
            }
        },
        {
            title: '显示右侧按钮',
            dataIndex: 'showRightButton',
            valueType: "radio",
            valueEnum: new Map([{ value: true, text: "是" }, { value: false, text: "否" }].map(item => [item.value, item.text])),
            formItemProps: {
                style: { marginBottom: 10 },
            },
            colProps: {
                span: 12
            },
        },
        {
            valueType: 'divider',
        },
        {
            valueType: 'formList',
            dataIndex: "configs",
            colProps: {
                span: 24
            },
            fieldProps: {
                max: 3,
                min: 3,
                creatorButtonProps: {
                    creatorButtonText: "添加一本书",
                },
                alwaysShowItemLabel: true,//全部展示title
                actionRender: (field: any, action: any, defaultActionDom: any, count: any) => {//自定义按钮
                    return [...defaultActionDom,
                    field.name < count - 1 && <Tooltip title="向下移动" key={`move-down-${field.name}`}><ArrowDownOutlined className={styles.upDownBtn} onClick={() => { action.move(field.name + 1, field.name) }} /></Tooltip>,
                    field.name > 0 && <Tooltip title="向上移动" key={`move-up-${field.name}`}><ArrowUpOutlined className={styles.upDownBtn} onClick={() => { action.move(field.name - 1, field.name) }} /></Tooltip>]
                }
            },
            columns: [
                {
                    valueType: 'group',
                    colProps: {
                        span: 24
                    },
                    columns: [
                        {
                            dataIndex: "bookId",
                            title: '小说',
                            colProps: {
                                span: 24
                            },
                            formItemProps: {
                                style: { marginBottom: 10 },
                                rules: [
                                    {
                                        required: true,
                                        message: '此项为必填项',
                                    },
                                ],
                            },
                            renderFormItem(schema, config, form, action) {
                                // return <BookSelect />
                                return <BookSelectDrawer />
                            },
                        },
                        {
                            valueType: 'divider',
                        }
                    ]
                }
            ]
        },

    ]
}