import { BetaSchemaForm, PageContainer, ProFormInstance, useToken } from "@ant-design/pro-components"
import { useAjax } from "@/Hook/useAjax"
import { useModel } from "@umijs/max"
import React, { JSXElementConstructor, Key, ReactElement, ReactNode, ReactPortal, useEffect, useMemo, useRef, useState } from "react"
import { appRechargeTemplateList, appRechargeTemplateSave, appRechargeTemplateSwitch, appRechargeTemplateRemove, appRechargeTemplateUpdate, appRechargeTemplateInfo } from "@/services/miniApp/moduleConfig"
import { Button, Card, Col, Empty, message, Modal, Row, Space } from "antd"
import { DeleteOutlined, EditOutlined, ExclamationCircleFilled, PlusOutlined } from "@ant-design/icons"
import { Template } from "./template"
import { createStyles } from "antd-style";
import DrawerBox from "./DrawerBox"
import { appComponentConfigList, remove, updateTemplate } from "@/services/miniApp/compConfig"
const useStyles = createStyles(({ token }) => {
    return {
        active: {
            position: 'relative',
            "&::after": {
                content: '""', // 修正了这里的拼写错误
                display: "block",
                opacity: 1,
                border: '15px solid #1890ff',
                borderBlockEnd: '15px solid transparent',
                borderInlineStart: '15px solid transparent', // 修正了多余的分号
                borderStartEndRadius: '6px',
                position: 'absolute',
                top: 0,
                right: 0
            }
        }
    }
})
type DataItem = {
    name: string;
    state: string;
};
const Page: React.FC = () => {
    let { token } = useToken()
    let { initialState } = useModel("@@initialState")
    let { dispatch } = useModel("appPageConifg")
    let [activeT, setActiveT] = useState<any>()
    let { styles } = useStyles()
    let getList = useAjax((params) => appComponentConfigList(params))//获取模板列表
    let switchT = useAjax((params) => updateTemplate(params))//切换
    let delT = useAjax((params) => remove(params))//删除
    const formRef = useRef<any>();
    const DrawerBoxRef = useRef<{ close: () => void; openDrawer: () => void }>(null);
    let publicData = useMemo(() => {
        return {
            appId: initialState?.selectApp?.id || "",
            appType: initialState?.selectApp?.appType || ""
        }
    }, [initialState?.selectApp, initialState?.currentUser?.distributorId])
    // 获取表单数据
    useEffect(() => {
        getList.run(publicData).then(res => {
            if (res.data) {
                let activeObj = res?.data?.find((item: { activateTemplate: any }) => item.activateTemplate)
                activeObj && setActiveT(activeObj.templateName)
            }
        })
    }, [publicData])
    // 模板切换
    const switchTemplate = (templateName: any) => {
        let params = { ...publicData, templateName }
        Modal.confirm({
            title: '切换组件模板',
            content: '是否要切换为当前组件模板？',
            icon: <ExclamationCircleFilled />,
            okText: "切换",
            onOk: () => {
                switchT.run(params).then(res => {
                    if (res.code === 200) {
                        setActiveT(templateName)
                        getList.refresh()
                        message.success("切换成功")
                    }
                })
            }
        });
    }
    // 模板删除
    const delTemplate = (templateName: any) => {
        let params = { ...publicData, templateName }
        Modal.confirm({
            title: '删除组件模板',
            content: '是否要删除当前组件模板？',
            icon: <ExclamationCircleFilled />,
            okType: 'danger',
            okText: "删除",
            onOk: () => {
                delT.run(params).then(res => {
                    if (res.code === 200) {
                        getList.refresh()
                        message.success("删除成功")
                    }
                })
            }
        });
    }
    // 编辑
    const edit = (data: any) => {
        console.log(" data?.templateName", data?.templateName, formRef.current[data?.templateName])
        let that = formRef.current[data?.templateName]
        dispatch({ type: 'setAll', params: { templateName: data?.templateName, pageConfigList: that?.pageConfigList,openEdit:true } })
        DrawerBoxRef?.current?.openDrawer();

    }
    return <PageContainer
        extra={getList?.data?.data?.length > 0 && <Button type="primary" onClick={DrawerBoxRef?.current?.openDrawer}><PlusOutlined />新增配置</Button>}
    >
        {/* 模板列表 */}
        <Row gutter={[20, 20]}>
            {
                getList?.data?.data?.map((item: any) => {
                    return <Col key={item.templateName} style={{ cursor: 'pointer' }} onClick={() => {
                        if (activeT !== item.templateName) {
                            switchTemplate(item.templateName)
                        }
                    }} >
                        <Card className={activeT === item.templateName ? styles.active : ""} style={{ background: activeT === item.templateName ? token.colorPrimaryBgHover : token.colorFillAlter }} hoverable>
                            <h3 style={{ fontSize: 16, fontWeight: 500, color: token.colorText, fontFamily: 'PingFang SC' }}>{item.templateName}</h3>
                            <Template data={item} formRef={formRef} />
                            <p style={{ marginTop: 20, color: token.colorTextSecondary, fontSize: 12 }}>{item.templateDescription}</p>
                            <div style={{ display: 'flex', alignItems: 'center', justifyContent: 'end' }}>
                                <Space>
                                    <Button size='small' type='primary' onClick={(e) => { e.stopPropagation(); edit(item) }}><EditOutlined /></Button>
                                    <Button size='small' type="primary" danger onClick={(e) => { e.stopPropagation(); delTemplate(item?.templateName) }}><DeleteOutlined /></Button>
                                </Space>
                            </div>
                        </Card>
                    </Col>
                })
            }
            {
                getList?.data?.data?.length === 0 && <div style={{ width: "100%", height: "100%", marginTop: "10%" }}><Empty description={<Space direction='vertical'><div>暂无模板数据</div><Button type="primary" onClick={DrawerBoxRef?.current?.openDrawer}><PlusOutlined />新增模板</Button></Space>} /></div>
            }
        </Row>
        {/* 模板弹窗 */}
        <DrawerBox ref={DrawerBoxRef} listApi={getList} />
    </PageContainer>

}
export default Page