import { ActionType, PageContainer, ProTable } from "@ant-design/pro-components"
import { columns } from "./tableConfig"
import { useAjax } from "@/Hook/useAjax"
import { history, useModel } from "@umijs/max"
import { Button } from "antd"
import { PlusCircleOutlined } from "@ant-design/icons"
import { listOfPage } from "@/services/miniApp/extend"
import { useEffect, useRef } from "react"
type Props = {
    isModal?: boolean
    value?: any
    onChange?: (v: any) => void
    onClose?: (v: any) => void
}
const Page: React.FC<Props> = (props) => {
    let { isModal, value } = props
    let { initialState } = useModel("@@initialState")
    let getList = useAjax((params) => listOfPage(params), { type: 'table' })
    let form = useRef<any>()
    // 当作为组件使用时首次打开存在链接名称以链接名称搜索
    useEffect(() => {
        if (value?.linkName && value?.bookName) {
            form?.current?.setFieldValue("linkName", value?.linkName)
            form?.current?.submit()
        }
    }, [])
    return <PageContainer title={false}
        header={isModal ? { breadcrumb: {} } : {}}
    >
        <ProTable<any, any>
            scroll={{ x: true }}
            toolBarRender={() => {
                return !isModal ? [
                    <Button
                        type="primary"
                        onClick={() => {
                            history.push("/miniApp/book")
                        }}
                    >
                        <PlusCircleOutlined />
                        新建作品链接
                    </Button>,
                ] : [];
            }}
            params={{
                appId: initialState?.selectApp?.id || "",
                appType: initialState?.selectApp?.appType || "",
                linkType: 1,
            }}
            headerTitle={"作品推广列表"}
            rowKey={(r) => r.linkId}
            //多选
            rowSelection={!!props?.onChange ? {
                hideSelectAll: true,
                type: 'radio',
                selectedRowKeys: [props?.value?.linkId || props?.value],
                onSelect: (record, selected) => {
                    props?.onClose?.(false)
                    props?.onChange?.(record)
                },
            } : false}
            // 点击行
            onRow={(record) => ({
                onClick: () => {
                    props?.onClose?.(false)
                    props?.onChange?.(record)
                }
            })}
            //多选展示按钮
            tableAlertOptionRender={false}
            //多选展示栏
            tableAlertRender={false}
            search={{
                labelWidth: 90,
                span: 6,
            }}
            formRef={form}
            request={async (params) => {
                return await getList.run(params)
            }}
            columns={columns(initialState?.selectApp?.appCategory || 1)}
        // bordered
        />
    </PageContainer>

}
export default Page