import { ProColumns } from "@ant-design/pro-components";
import { useModel } from "@umijs/max";
import { Badge } from "antd";

export const columns = (): ProColumns<any>[] => {
    let {getEnum} = useModel("global")
    let payChannelObj: any = { '1': '微信小程序支付' };
    let orderTypeObj: any = { '1': '书币充值', "2": "vip充值", "3": "购买整本" };
    let orderStatusObj: any = { '1': '待支付', "2": "已支付" };
    return [
        {
            title: 'openId',
            dataIndex: 'openId',
            align: 'center',
            width: 70,
            ellipsis: true,
            render: (_, row) => {
                return row?.wechatMiniappUser?.openId
            }
        },
        {
            title: "小说名称",
            dataIndex: 'bookName',
            key: "bookName",
            align: "center",
            render: (a, b: any) => {
                return b?.bookInfo?.bookName
            }
        },
        {
            title: "支付渠道",
            dataIndex: 'payChannel',
            key: "payChannel",
            align: "center",
            valueType: 'select',
            valueEnum: payChannelObj,
            render: (a: any, b: any) => {
                return payChannelObj[b.payChannel]
            },
        },
        {
            title: "支付金额",
            dataIndex: 'amount',
            key: "amount",
            hideInSearch: true,
            align: "center",
        },
        {
            title: "订单类型",
            dataIndex: 'orderType',
            key: "orderType",
            valueType: 'select',
            valueEnum: orderTypeObj,
            align: "center",
            render: (a: any, b: any) => {
                return orderTypeObj[b.orderType]
            }
        },
        {
            title: "订单状态",
            dataIndex: 'orderStatus',
            key: "orderStatus",
            valueType: 'select',
            valueEnum: orderStatusObj,
            align: "center",
            render: (a: any, b: any) => {
                return <Badge text={orderStatusObj[b.orderStatus]} status={b.orderStatus != 1 ? "success" : "warning"} />
            }
        },
        {
            title: "用户订单号",
            dataIndex: 'orderId',
            key: "orderId",
            align: "center",
        },
        {
            title: "商户订单号",
            dataIndex: 'merchantOrderId',
            key: "merchantOrderId",
            align: "center",
        },
        {
            title: "下单时间",
            dataIndex: 'orderTime',
            key: "orderTime",
            hideInSearch: true,
            align: "center",
        },
        {
            title: "下单场景",
            dataIndex: 'orderCondition',
            key: "orderCondition",
            hideInSearch: true,
            align: "center",
        },
        {
            title: "支付时间",
            tooltip: "实际到账时间",
            dataIndex: 'payTime',
            key: "payTime",
            hideInSearch: true,
            align: "center",
        },
        {
            title: '归因渠道',
            dataIndex: 'userChannel',
            width: 170,
            align: 'center',
            ellipsis: true,
            valueType: 'select',
            valueEnum: getEnum("USER_CHANNEL", "map"),
            render: (_, row) => {
                let str = getEnum("USER_CHANNEL", "map").get(row?.wechatMiniappUser?.userChannel)
                return str
            }
        },
        // 搜索条件
        {
            title: "开始时间",
            dataIndex: 'startTime',
            valueType: 'dateTime',
            hideInTable: true
        },
        {
            title: "结束时间",
            dataIndex: 'endTime',
            valueType: 'dateTime',
            hideInTable: true
        },
        {
            title: "最小充值金额",
            dataIndex: 'amountMin',
            valueType: 'money',
            hideInTable: true,
        },
        {
            title: "最大充值金额",
            dataIndex: 'amountMax',
            valueType: 'money',
            hideInTable: true
        },
    ];
}